/**
 * @brief 
 * 
 * This file is a part of PFSTOOLS package.
 * ---------------------------------------------------------------------- 
 * Copyright (C) 2003,2004 Rafal Mantiuk and Grzegorz Krawczyk
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ---------------------------------------------------------------------- 
 *
 * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
 *
 * $Id: main.h,v 1.1 2005/06/15 13:36:55 rafm Exp $
 */

#ifndef MAIN_H
#define MAIN_H

#include <qapplication.h>
#include <qmainwindow.h>
#include <qmessagebox.h>
#include <qlayout.h>
#include <qpopupmenu.h>
#include <qmenubar.h>
#include <qsplitter.h>

#include <list>

#include "pfsview_widget.h"

#define MAX_FRAMES_IN_MEMORY 5

class LuminanceRangeWidget;
class QComboBox;

class pfs::Frame;


class PFSViewMainWin : public QMainWindow {
  Q_OBJECT
public:
    PFSViewMainWin( float window_min, float window_max );
    
public slots:
    void changeClippingMethod( int clippingMethod );
    void updatePointerValue();
    void updateRangeWindow();
    void updateViewSize();
    void updateChannelSelection();
    void setChannelSelection( int selectedChannel );
    void updateZoomValue();
    void gotoNextFrame();
    void gotoPreviousFrame();
    void saveImage();
    void setInfNaNTreatment( int method );
    void setNegativeTreatment( int method );
    void setLumMappingMethod( int method );
  
private:
    void setFrame( pfs::Frame *frame );

    int clippingMethodMI[CLIP_COUNT];
    int infNaNMI[2];
    int negativeMI[NEGATIVE_COUNT];
    
    QPopupMenu *viewMenu;
    QPopupMenu *infnanMenu, *negativeMenu;
    QLabel *pointerPosAndVal, *zoomValue;
    PFSViewWidget *pfsView;
    LuminanceRangeWidget *lumRange;
    QComboBox *channelSelection;
    QComboBox *mappingMethodCB;
    QStatusBar *statusBar;

    bool readNextFrame();

    std::list<pfs::Frame*> frameList;
    std::list<pfs::Frame*>::iterator currentFrame;    
    
public:

    PFSViewWidget *getPFSViewWidget() 
      {
        return pfsView;
      }
    
};

#endif
